Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2609)

Unified Diff: chrome/browser/ui/views/frame/opaque_browser_frame_view.h

Issue 10736063: views: Extract TabIconViewModel into its own header file. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/opaque_browser_frame_view.h
diff --git a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
index 01706f0066a88cb5139caafe8f744392a41a3aad..76d321be4dbfec8ec016b9fc77abe9a83876e988 100644
--- a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
@@ -8,13 +8,15 @@
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/ui/views/frame/browser_frame.h"
#include "chrome/browser/ui/views/frame/browser_non_client_frame_view.h"
-#include "chrome/browser/ui/views/tab_icon_view.h"
+#include "chrome/browser/ui/views/tab_icon_view_model.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "ui/views/controls/button/button.h"
#include "ui/views/window/non_client_view.h"
class BrowserView;
+class TabIconView;
+
namespace views {
class ImageButton;
class FrameBackground;
@@ -23,7 +25,7 @@ class FrameBackground;
class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
public content::NotificationObserver,
public views::ButtonListener,
- public TabIconView::TabIconViewModel {
+ public chrome::TabIconViewModel {
public:
// Constructs a non-client view for an BrowserFrame.
OpaqueBrowserFrameView(BrowserFrame* frame, BrowserView* browser_view);
@@ -71,7 +73,7 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
virtual void ButtonPressed(views::Button* sender, const views::Event& event)
OVERRIDE;
// Overridden from TabIconView::TabIconViewModel:
virtual bool ShouldTabIconViewAnimate() const OVERRIDE;
virtual gfx::ImageSkia GetFaviconForTabIconView() OVERRIDE;
@@ -71,7 +73,7 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
virtual void ButtonPressed(views::Button* sender, const views::Event& event)
OVERRIDE;
- // Overridden from TabIconView::TabIconViewModel:
+ // Overridden from chrome::TabIconViewModel:
virtual bool ShouldTabIconViewAnimate() const OVERRIDE;
virtual gfx::ImageSkia GetFaviconForTabIconView() OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698